@@ -77,6 +77,38 @@ def _post_with_auth(url, data, auth):
     return _post(url, data, None, qiniu.auth.RequestsAuth(auth))
 
 
+def _post_with_qiniu_mac(url, data, auth):
+
+    qn_auth = qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None
+    timeout = config.get_default('connection_timeout')
+
+    try:
+        r = requests.post(url, json=data, auth=qn_auth, timeout=timeout, headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
+def _get_with_qiniu_mac(url, params, auth):
+    try:
+        r = requests.get(
+            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'), headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
+def _delete_with_qiniu_mac(url, params, auth):
+    try:
+        r = requests.delete(
+            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'), headers=_headers)
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
 class ResponseInfo(object):
     """七牛HTTP请求返回信息类
 
